@@ -1,6 +1,4 @@
-extern crate sha3;
-
-use sha3::{Sha3_256, Digest};
+use sha3::{Digest, Sha3_512};
 use std::env;
 use std::fs;
 use std::io::{self, Read};
@@ -25,12 +23,12 @@ fn process<D: Digest + Default, R: Read>(reader: &mut R, name: &str) {
             Ok(n) => n,
             Err(_) => return,
         };
-        sh.input(&buffer[..n]);
+        sh.update(&buffer[..n]);
         if n == 0 || n < BUFFER_SIZE {
             break;
         }
     }
-    print_result(&sh.result(), name);
+    print_result(&sh.finalize(), name);
 }
 
 fn main() {
@@ -40,10 +38,10 @@ fn main() {
     if args.len() > 1 {
         for path in args.skip(1) {
             if let Ok(mut file) = fs::File::open(&path) {
-                process::<Sha3_256, _>(&mut file, &path);
+                process::<Sha3_512, _>(&mut file, &path);
             }
         }
     } else {
-        process::<Sha3_256, _>(&mut io::stdin(), "-");
+        process::<Sha3_512, _>(&mut io::stdin(), "-");
     }
 }
